@@ -105,7 +105,7 @@ static int parse_line(
 static int
 parse_line(char *l, char *param, char *value)
 {
-    char *p;
+    char *p, *start;
     size_t le, len;
     enum modes { plain, quoted } mode = plain;
 
@@ -135,11 +135,16 @@ parse_line(char *l, char *param, char *value)
 	    break;
     }
 
+    start = value;
     /* read value */
     for (le = 0 ; le < TOKENSIZE - 1 ; le ++) {
 	char c = *p++;
 	if (mode == plain) {
-	    if (c == '#' || c == '\0') { break; }
+	    if (c == '#' || c == '\0') {
+		/* strip trailing blanks */
+		while(value > start && strchr(" \t", value[-1])) value--;
+		break;
+	    }
 	    if (c == '"') { mode = quoted; continue; }
 	    *value++ = c;
 	} else if (mode == quoted) {
