@@ -10,11 +10,8 @@ pcre *gs_compile(const char *regex) {
     int regex_errpos;
     pcre *e;
 
-    if ((e = pcre_compile(regex, PCRE_MULTILINE, &regex_errmsg, &regex_errpos
-#ifdef NEW_PCRE_COMPILE
-		    , NULL
-#endif
-		    )) == NULL) {
+    if ((e = pcre_compile(regex, PCRE_MULTILINE, &regex_errmsg,
+		    &regex_errpos, NULL)) == NULL) {
 	ln_log(LNLOG_SERR, LNLOG_CTOP, "Invalid group pattern "
 		"in \"%s\" at char #%d: %s", regex, regex_errpos, regex_errmsg);
     }
@@ -27,10 +24,7 @@ pcre *gs_compile(const char *regex) {
 int gs_match(const pcre *p, const char *s) {
     int match;
     if (p == NULL) return 1;
-    match = pcre_exec(p, NULL, s, strlen(s),
-#ifdef NEW_PCRE_EXEC
-	    0,
-#endif
+    match = pcre_exec(p, NULL, s, strlen(s), 0,
 	    PCRE_ANCHORED, NULL, 0);
 
     if (match == PCRE_ERROR_NOMATCH) return 0;
