@@ -215,7 +215,7 @@ initvars(char *progname)
 	if (e) {
 	    syslog(LOG_ERR, "%s: setting group id to %ld failed: %s",
 		    progname, (long)pw->pw_gid, strerror(errno));
-	    fprintf(stderr, "%s: setting group id to %ld failed: %s",
+	    fprintf(stderr, "%s: setting group id to %ld failed: %s\n",
 		    progname, (long)pw->pw_gid, strerror(errno));
 	}
 
@@ -225,10 +225,10 @@ initvars(char *progname)
 	e = setreuid(pw->pw_uid, pw->pw_uid);
 #endif
 	if (e) {
-	    syslog(LOG_ERR, "%s: setting user id to %ld failed: %s",
-		    progname, (long)pw->pw_uid, strerror(errno));
-	    fprintf(stderr, "%s: setting user id to %ld failed: %s",
-		    progname, (long)pw->pw_uid, strerror(errno));
+	    syslog(LOG_ERR, "%s: setting user id to %ld failed: %s. (Real uid is %ld, effective %ld)",
+		    progname, (long)pw->pw_uid, strerror(errno), (long)getuid(), (long)geteuid());
+	    fprintf(stderr, "%s: setting user id to %ld failed: %s. (Real uid is %ld, effective %ld)\n",
+		    progname, (long)pw->pw_uid, strerror(errno), (long)getuid(), (long)geteuid());
 	}
 
 	/* extra sanity check - read back the new values */
@@ -487,7 +487,33 @@ chdirgroup(const char *group, int creatdir)
     return 0;
 }
 
+#ifdef HAVE_IPV6
 /* get the fully qualified domain name of this box into fqdn */
+/* IPv6-capable version by Boris Manojlovic <boris@steki.net> */
+static void
+whoami(void)
+{
+    struct addrinfo hints, *res;
+    int debugqual = 0;
+    char *x;
+
+    if ((x = getenv("LN_DEBUG_QUALIFICATION")) != NULL
+	&& *x)
+	debugqual = 1;
+    memset(&hints, 0, sizeof hints);
+    hints.ai_flags = AI_CANONNAME;
+
+    if (!gethostname(fqdn, sizeof(fqdn)) && !getaddrinfo(fqdn, NULL, &hints, &res)) {
+	if (res->ai_canonname != NULL) {
+            xstrlcpy(fqdn,res->ai_canonname, sizeof(fqdn));
+            if (debugqual) syslog(LOG_DEBUG, "canonical hostname: %s", fqdn);
+        }
+        freeaddrinfo(res);
+    }
+}
+#else
+/* get the fully qualified domain name of this box into fqdn */
+/* legacy version, uses legacy (IPv4) gethostby*() interfaces */
 static void
 whoami(void)
 {
@@ -520,6 +546,7 @@ whoami(void)
 	endhostent();
     }
 }
+#endif
 
 /*
  * prepend string "newentry" to stringlist "list".
